<?php

namespace Drupal\mfd\Plugin\Field\FieldType;

use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;


/**
 * Plugin implementation of the 'multilingual_form_display' field type.
 *
 * @FieldType(
 *   id = "multilingual_form_display",
 *   label = @Translation("Multilingual Form Display"),
 *   description = @Translation("This field exposed all other fields of an entity which set translatable."),
 *   category = @Translation("Multilingual"),
 *   default_widget = "multilingual_form_display_widget",
 *   default_formatter = "multilingual_form_display_formatter",
 *   cardinality = 1,
 * )
 */
class MultilingualFormDisplayType extends FieldItemBase {

  //TODO: Convert this field value to store for each entity the state of all the
  // language translations. This could be a simple way to store and read this
  // for other reasons like (Views integration or API reviewing of the content type
  // when doing syndication. Slightly kludgy though. Best, would be to find the
  // right way to drop the fieldtype and use a computedField instead.

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Field Note'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'value' => [
          'type' => 'text',
          'size' => 'normal',
          'not null' => FALSE,
        ],
      ],
    ];
  }

}
